# 7.2 O modelo mais simples possível

anim.m2 <- lm(log(brain) ~ log(body), data = Animals, 
              subset =! (log(Animals$body)> 8 & log(Animals$brain) < 6))

plot(log(brain) ~ log(body), data = Animals, 
     subset =! (log(Animals$body)> 8 & log(Animals$brain) < 6))
abline(anim.m2, col = "red", lty = 2)

plot(anim.m2)


anim.m0 <- lm(log(brain) ~ 1, data = Animals, 
              subset =! (log(Animals$body) > 8 & log(Animals$brain) < 6))

anova(anim.m0,anim.m2)

# 1. Qual a relação do comando 'anova' acima com:

anova(anim.m2)

# O comando anova(anim.m2) mostra a tabela de partição de variâncias para o modelo m2 apenas, enquanto o 
#+ anterior compara dois modelos (m2, modelo mais complexo, e modelo nulo, mais simples).

# 2. Qual a relação entre os valores obtidos por estes comandos:

summary(anim.m0) # linha 1
mean(log(Animals$brain [!(log(Animals$body) > 8 & log(Animals$brain) < 6)])) # linha 2
sd(log(Animals$brain [!(log(Animals$body) > 8 & log(Animals$brain) < 6)])) # linha 3

# O primeiro comando (linha 1) mostra o summary do modelo, incluindo o valor estimado do intercepto (que eh a 
#+ media geral do log , calculada na linha abaixo) e o erro padrao dos residuos, que foi calculado na linha 3;
# No modelo nulo, o intercepto se iguala a media, pois a inclinacao eh zero e a reta representa a propria media.
#+ O desvio padrao calculado, por outro lado, representa o desvio das medicoes com relacao a media, que, no
#+ modelo nulo eh igual ao desvio dos residuos em relacao ao modelo (que eh a propria media).

anim.m0 <- update(anim.m2, .~. -log(body))
abline(anim.m0, col = "blue", lty = 2)

############################################################################################

#### 7b. Exercícios de Regressão Múltipla

## 1. Uma estimativa da incerteza na previsão do modelo

# Selecionando dados em babies
bebes <- read.table("babies.csv", header = TRUE, as.is = TRUE, sep = " ")
head(bebes)
range(bebes$bwt)
range(bebes$gestation)
bebes <- subset(bebes, bebes$bwt < 999)
bebes <- subset(bebes, bebes$gestation < 999)
bebes$bwt <- bebes$bwt*0.0283495231
head(bebes)

# Criando um vetor representativo da variável preditora (x.gest)
x.gest <- seq(148, 353, length.out = 100)
x.gest

# Gerando o modelo linear (lm.bebes) e encontrando os coeficientes (a e b)
lm.bebes <- lm(bebes$bwt ~ bebes$gestation)
lm.bebes
summary(lm.bebes)
av.lm.bebes <- anova(lm.bebes)
av.lm.bebes
coef(lm.bebes)
a <- lm.bebes$coefficients[1]
b <- lm.bebes$coefficients[2]

# Calculando o erro padrão (se)
#SSX1 <- v.lm.bebes$`Sum Sq`[1]
n <- length(bebes$bwt)
var.bwt <- var(bebes$bwt)
media.gest <- mean(bebes$gestation)
SSX <- sum((bebes$gestation - mean(bebes$gestation))^2)

se <- sqrt(var.bwt*((1/n) + (((x.gest - media.gest)^2)/SSX)))
se

# Encontrando o valor de t 
t <-qt(0.975, n-2) 
t

# Encontrando os valores de y para x.gest
bwt.pred <- a + b*x.gest
bwt.pred

# Calculando os intervalos de confiança
pos <- bwt.pred + (se*t)
pos
neg <- bwt.pred - (se*t)
neg

# Plotando o gráfico final
quartz()
par( mar=c(4.5,5,2,2),   cex.lab=1.5, cex.axis=1.2, las=1, bg = "white", bty="n")
plot(NA, type="n", axes = FALSE, ann = FALSE, xlim =range(bebes$gestation), ylim = range(bebes$bwt)) 
points(bebes$bwt ~ bebes$gestation, pch = 19,cex= 1.5, col = c(rgb(0.3,0,0.8,0.4)))
axis(1)
axis(2)
mtext("Massa ao nascer (kg)", 2, line=3, cex = 1.7, las = 0)
mtext("Gestação (dias)", 1, line=2.5, cex = 1.7, las = 0)
lines(x = x.gest, y = pos, col = c(rgb(1,0,0,0.3)))
lines(x = x.gest, y = neg, col = c(rgb(1,0,0,0.3)))
polygon(c(rev(x.gest), x.gest), c(rev(neg), pos), col = rgb(1,0,0,0.2), border = NA)
clip(min(x.gest), max(x.gest), min(bwt.pred), max(bwt.pred))
abline(lm.bebes, col = "red") # Mudei abline para o fim para poder delimitar com o clip!!!

############################################################################################

## 2. Galileu estava certo?

# Dados
library(UsingR)
data(galileo)

init.h = c(600, 700, 800, 950, 1100, 1300, 1500)
h.d = c(253, 337, 395, 451, 495, 534, 573)

# Plotando os dados
plot(h.d~init.h)

# Modelos concorrentes
# 1. y = a+bx
mod1 <- lm(h.d~init.h)
# 2. y = a+bx+cx^2
mod2 <- update(mod1,.~. +I(init.h^2))
# 3. y = a+bx+cx^2+dx^3
mod3 <- update(mod2,.~. +I(init.h^3))

# Comparando os modelos
anova(mod1, mod2, mod3)

# Adicionando as curvas dos modelos no gráfico
abline(mod1, col = c(rgb(1,0,0,0.5)), lty = 2)
cf.m2 <- coef(mod2)
curve(cf.m2[1]+cf.m2[2]*x+cf.m2[3]*x^2, add=T, lty=2, col = c(rgb(0,1,0,0.5)))
cf.m3 <- coef(mod3)
curve(cf.m3[1]+cf.m3[2]*x+cf.m3[3]*x^2+cf.m3[4]*x^3, add=T, lty=2, col = c(rgb(0,0,1,0.5)))
legend("bottomright",c("Modelo 1 (y = a+bx)", "Modelo 2 (y = a+bx+cx^2)", "Modelo 3 (y = a+bx+cx^2+dx^3)"),  pch=19,
       col = c(c(rgb(1,0,0,0.5)), c(rgb(0,1,0,0.5)), c(rgb(0,0,1,0.5))), bty="n", bg= "white", cex= 1)

# Um polinomio de terceiro grau parece explicar melhor os dados de Galileu.


############################################################################################

## 3. Massa de Recém-Nascidos

setwd("~/Desktop/R/Curso_Eco/Exercicios_tabela/")

bebes <- read.table("babies.csv", header = TRUE, as.is = TRUE, sep = " ")
head(bebes)
range(bebes$bwt)
range(bebes$gestation)
bebes <- subset(bebes, bebes$bwt < 999)
bebes <- subset(bebes, bebes$gestation < 999)
bebes <- subset(bebes, bebes$age < 99)
bebes <- subset(bebes, bebes$height < 99)
bebes <- subset(bebes, bebes$weight < 999)
bebes <- subset(bebes, bebes$smoke < 9)
bebes <- subset(bebes, bebes$parity < 9)
bebes$bwt <- bebes$bwt*0.0283495231
bebes$bwt <- round(bebes$bwt, 2)
head(bebes)

# Criando os modelos
# Cheio
lm.full <- lm(bwt ~ gestation + age + smoke + gestation:age + gestation:smoke + age:smoke + gestation:age:smoke,
              data = bebes) # todas as interacoes possiveis devem ser consideradas!!!!
summary(lm.full)

# Simplificando o modelo, sem gestation:age:smoke
lm.01 <- lm(bwt ~ gestation + age + smoke + gestation:age + gestation:smoke + age:smoke, data = bebes)
summary(lm.01)

# Comparando o lm.full e lm.01
av.full.01 <- anova(lm.full, lm.01)
av.full.01 # Interação tripla gestation:age:smoke parece não ser importante

# Simplificando mais o modelo, sem age:smoke
lm.02 <- lm(bwt ~ gestation + age + smoke + gestation:age + gestation:smoke, data = bebes) 
summary(lm.02)

# Comparando o lm.01 e lm.02
av.01.02 <- anova(lm.01, lm.02)
av.01.02 # Interação age:smoke não parece importante

# Simplificando mais o modelo 02, sem gestation:smoke
lm.03 <- lm(bwt ~ gestation + age + smoke + gestation:age, data = bebes) 
summary(lm.03)

# Comparando o lm.01 e lm.03
av.02.03 <- anova(lm.02, lm.03)
av.02.03 # Interação gestation:smoke parece importante

## Simplificando mais o modelo 02, sem gestation:age
lm.04 <- lm(bwt ~ gestation + age + smoke + gestation:smoke, data = bebes) 
summary(lm.04)

# Comparando o lm.02 e lm.04
av.02.04 <- anova(lm.02, lm.04)
av.02.04 # Interação gestation:age parece importante

# Comparando todos
av.all <- anova(lm.full, lm.01, lm.02, lm.03, lm.04)
av.all 

# o modelo mais adequado parece ser o modelo 02, que inclui as variaveis gestation, age, smoke  e as interações
#+ gestation:age e gestation:smoke.